@@ -62,8 +62,9 @@ def _retinamask_data(im, semantic=False):
     boxes[..., :] = rp
 
     # scores
-    scores = np.zeros((n_batch, n_det, 1))
-    scores[..., :] = np.random.rand()
+    scores = np.random.random(size=(n_batch, n_det, 1))
+    # set one score to .999 to force a match
+    scores[:, 0, 0] = .999
 
     # labels
     labels = np.zeros((n_batch, n_det, n_labels))
